Cheshire3 Configuration: Common References

|  | ## Cheshire3 Configuration: Common References

Introduction

Below are the commonly required or used paths, objects and settings for the configuration files.

Paths

- defaultPath
  A default path to be prepended to all other paths in the object and below
- metadataPath
  Used to point to a database file or directory for metadata concerning the object
- databasePath
  Used in store objects to point to a database file or directory
- tempPath
  For when temporary file(s) are required.
- schemaPath
  Used in Parsers to point to a validation document (eg xsd, dtd, rng)
- xsltPath
  Used in XsltTransformers to point to the XSLT document to use.
- sortPath
  Used in IndexStores to refer to the local 'sort' utility

Settings

- log
  This contains a space separated list of function names to log on invocation. The functionLogger object referenced in paths will be used to do this.
- digest
  Used in recordStores to name a digest algorithm to determine if a record is already present in the store. Currently supported are 'sha' and 'md5'.